summaryrefslogtreecommitdiffstats
path: root/kmymoney2/reports/listtable.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/reports/listtable.h')
-rw-r--r--kmymoney2/reports/listtable.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kmymoney2/reports/listtable.h b/kmymoney2/reports/listtable.h
index 5ffa64d..1397a93 100644
--- a/kmymoney2/reports/listtable.h
+++ b/kmymoney2/reports/listtable.h
@@ -23,7 +23,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstringlist.h>
+#include <tqstringlist.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -54,10 +54,10 @@ namespace reports {
{
public:
ListTable ( const MyMoneyReport& );
- QString renderHTML ( void ) const;
- QString renderCSV ( void ) const;
+ TQString renderHTML ( void ) const;
+ TQString renderCSV ( void ) const;
void drawChart ( KReportChartView& ) const {}
- void dump ( const QString& file, const QString& context = QString() ) const;
+ void dump ( const TQString& file, const TQString& context = TQString() ) const;
void init ( void );
public:
@@ -65,10 +65,10 @@ namespace reports {
* Contains a single row in the table.
*
* Each column is a key/value pair, both strings. This class is just
* a QMap with the added ability to specify which columns you'd like to
* use as a sort key when you qHeapSort a list of these TableRows
*/
- class TableRow: public QMap<QString, QString>
+ class TableRow: public TQMap<TQString, TQString>
{
public:
bool operator< ( const TableRow& ) const;
@@ -76,15 +76,15 @@ namespace reports {
bool operator> ( const TableRow& ) const;
bool operator== ( const TableRow& ) const;
- static void setSortCriteria ( const QString& _criteria ) { m_sortCriteria = QStringList::split ( ",", _criteria ); }
+ static void setSortCriteria ( const TQString& _criteria ) { m_sortCriteria = TQStringList::split ( ",", _criteria ); }
private:
- static QStringList m_sortCriteria;
+ static TQStringList m_sortCriteria;
};
- QValueList<TableRow> rows() {return m_rows;};
+ TQValueList<TableRow> rows() {return m_rows;};
protected:
- void render ( QString&, QString& ) const;
+ void render ( TQString&, TQString& ) const;
/**
* If not in expert mode, include all subaccounts for each selected
@@ -92,23 +92,23 @@ namespace reports {
*/
void includeInvestmentSubAccounts(void);
- QValueList<TableRow> m_rows;
+ TQValueList<TableRow> m_rows;
- QString m_group;
+ TQString m_group;
/**
* Comma-separated list of columns to place BEFORE the subtotal column
*/
- QString m_columns;
+ TQString m_columns;
/**
* Name of the subtotal column
*/
- QString m_subtotal;
+ TQString m_subtotal;
/**
* Comma-separated list of columns to place AFTER the subtotal column
*/
- QString m_postcolumns;
- QString m_summarize;
- QString m_propagate;
+ TQString m_postcolumns;
+ TQString m_summarize;
+ TQString m_propagate;
MyMoneyReport m_config;
@@ -65,10 +65,10 @@ namespace reports {
*
* Each column is a key/value pair, both strings. This class is just
- * a QMap with the added ability to specify which columns you'd like to
+ * a TQMap with the added ability to specify which columns you'd like to
* use as a sort key when you qHeapSort a list of these TableRows
*/